@@ -145,11 +145,12 @@ impl ShredFetchStage {
             .map(|s| {
                 streamer::receiver(
                     s,
-                    &exit,
+                    exit,
                     packet_sender.clone(),
                     recycler.clone(),
                     "packet_modifier",
                     1,
+                    true,
                 )
             })
             .collect();
@@ -173,7 +174,7 @@ impl ShredFetchStage {
 
         let (mut tvu_threads, tvu_filter) = Self::packet_modifier(
             sockets,
-            &exit,
+            exit,
             sender.clone(),
             recycler.clone(),
             bank_forks.clone(),
@@ -183,7 +184,7 @@ impl ShredFetchStage {
 
         let (tvu_forwards_threads, fwd_thread_hdl) = Self::packet_modifier(
             forward_sockets,
-            &exit,
+            exit,
             sender.clone(),
             recycler.clone(),
             bank_forks.clone(),
@@ -193,7 +194,7 @@ impl ShredFetchStage {
 
         let (repair_receiver, repair_handler) = Self::packet_modifier(
             vec![repair_socket],
-            &exit,
+            exit,
             sender.clone(),
             recycler,
             bank_forks,
